@@ -19,7 +19,7 @@
 #ifndef ACCOUNT_INFO_WIDGET
 #define ACCOUNT_INFO_WIDGET
 
-#include <QtCore/QModelIndex>
+#include <QModelIndex>
 
 #include <QWidget>
 #include <QStringList>
@@ -35,7 +35,7 @@ class AccountInfo : public QWidget
 {
     Q_OBJECT
     public:
-        explicit AccountInfo(AccountModel* model, QWidget* parent = nullptr, Qt::WindowFlags f = 0);
+        explicit AccountInfo(AccountModel* model, QWidget* parent = nullptr, Qt::WindowFlags f = {});
         virtual ~AccountInfo();
 
         void setModelIndex(const QModelIndex &index);
