@@ -26,7 +26,7 @@
 
 #include <pwquality.h>
 
-#include <QtCore/QDebug>
+#include <QDebug>
 #include <QListView>
 #include <QVBoxLayout>
 
@@ -36,7 +36,6 @@
 #include <KIconLoader>
 
 K_PLUGIN_FACTORY(UserManagerFactory, registerPlugin<UserManager>();)
-K_EXPORT_PLUGIN(UserManagerFactory("user_manager", "user_manager"))
 
 UserManager::UserManager(QWidget* parent, const QVariantList& args) 
  : KCModule(parent, args)
@@ -124,7 +123,7 @@ void UserManager::removeUser()
 
     QString warning = i18n("What do you want to do after deleting %1 ?", m_model->data(index, AccountModel::FriendlyName).toString());
     if (!m_model->data(index, AccountModel::Logged).toBool()) {
-        warning.append("\n\n");
+        warning.append(QStringLiteral("\n\n"));
         warning.append(i18n("This user is using the system right now, removing it will cause problems"));
     }
 
